Module vae

Module vae 

Variational Autoencoder (SD 2.1 compatible).

Encodes images to latent space and decodes latents back to pixel space. This is a simplified but functional VAE that mirrors the architecture used in Stable Diffusion 2.1.

Structs

Vae
Variational Autoencoder for encoding/decoding between pixel and latent space.